@@ -26,39 +26,39 @@ import java.util.Date;
 import javax.xml.namespace.QName;
 
 import org.apache.cxf.aegis.AbstractAegisTest;
+import org.apache.cxf.aegis.AegisContext;
 import org.apache.cxf.aegis.Context;
 import org.apache.cxf.aegis.services.SimpleBean;
-import org.apache.cxf.aegis.type.Configuration;
-import org.apache.cxf.aegis.type.DefaultTypeMappingRegistry;
 import org.apache.cxf.aegis.type.Type;
+import org.apache.cxf.aegis.type.TypeCreationOptions;
 import org.apache.cxf.aegis.type.TypeMapping;
-import org.apache.cxf.aegis.util.XmlConstants;
 import org.apache.cxf.aegis.util.jdom.StaxBuilder;
 import org.apache.cxf.aegis.xml.jdom.JDOMReader;
 import org.apache.cxf.aegis.xml.jdom.JDOMWriter;
 import org.apache.cxf.aegis.xml.stax.ElementReader;
 import org.apache.cxf.aegis.xml.stax.ElementWriter;
+import org.apache.cxf.common.util.SOAPConstants;
 import org.jdom.Document;
 import org.jdom.Element;
-import org.jdom.output.DOMOutputter;
 import org.junit.Test;
 
 public class BeanTest extends AbstractAegisTest {
     TypeMapping mapping;
-    private DefaultTypeMappingRegistry reg;
+    private AegisContext context;
 
     public void setUp() throws Exception {
         super.setUp();
-
+    
         addNamespace("b", "urn:Bean");
-        addNamespace("bz", "urn:beanz");
         addNamespace("a", "urn:anotherns");
-        addNamespace("xsi", XmlConstants.XSI_NS);
+        addNamespace("xsi", SOAPConstants.XSI_NS);
 
-        reg = new DefaultTypeMappingRegistry(true);
-        mapping = reg.createTypeMapping(true);
+        context = new AegisContext();
+        context.initialize();
+        mapping = context.getTypeMapping();
     }
 
+    @Test
     public void testBean() throws Exception {
         BeanType type = new BeanType();
         type.setTypeClass(SimpleBean.class);
@@ -68,7 +68,7 @@ public class BeanTest extends AbstractAegisTest {
         // Test reading
         ElementReader reader = new ElementReader(getResourceAsStream("bean1.xml"));
 
-        SimpleBean bean = (SimpleBean)type.readObject(reader, new Context());
+        SimpleBean bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("bleh", bean.getBleh());
         assertEquals("howdy", bean.getHowdy());
 
@@ -76,14 +76,14 @@ public class BeanTest extends AbstractAegisTest {
 
         // Test reading with extra elements
         reader = new ElementReader(getResourceAsStream("bean2.xml"));
-        bean = (SimpleBean)type.readObject(reader, new Context());
+        bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("bleh", bean.getBleh());
         assertEquals("howdy", bean.getHowdy());
         reader.getXMLStreamReader().close();
 
         // test <bleh/> element
         reader = new ElementReader(getResourceAsStream("bean7.xml"));
-        bean = (SimpleBean)type.readObject(reader, new Context());
+        bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("", bean.getBleh());
         assertEquals("howdy", bean.getHowdy());
         reader.getXMLStreamReader().close();
@@ -93,24 +93,12 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertValid("/b:root/b:bleh[text()='bleh']", element);
         assertValid("/b:root/b:howdy[text()='howdy']", element);
     }
-
-    private void assertValid(String xpath, Element element) throws Exception {
-        org.w3c.dom.Document doc = new DOMOutputter().output(element.getDocument());
-
-        assertValid(xpath, doc);
-    }
-
-    private void assertInvalid(String xpath, Element element) throws Exception {
-        org.w3c.dom.Document doc = new DOMOutputter().output(element.getDocument());
-
-        assertInvalid(xpath, doc);
-    }
-
+    
     @Test
     public void testBeanWithXsiType() throws Exception {
         BeanType type = new BeanType();
@@ -120,9 +108,8 @@ public class BeanTest extends AbstractAegisTest {
 
         // Test reading
         ElementReader reader = new ElementReader(getResourceAsStream("bean9.xml"));
-
-        Context ctx = new Context();
-        ctx.setReadXsiTypes(false);
+        Context ctx = getContext();
+        ctx.getGlobalContext().setReadXsiTypes(false);
 
         SimpleBean bean = (SimpleBean)type.readObject(reader, ctx);
         assertEquals("bleh", bean.getBleh());
@@ -133,7 +120,7 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertValid("/b:root/b:bleh[text()='bleh']", element);
         assertValid("/b:root/b:howdy[text()='howdy']", element);
@@ -157,7 +144,7 @@ public class BeanTest extends AbstractAegisTest {
 
         ElementReader reader = new ElementReader(getResourceAsStream("bean3.xml"));
 
-        SimpleBean bean = (SimpleBean)type.readObject(reader, new Context());
+        SimpleBean bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("howdy", bean.getHowdy());
         assertNull(bean.getBleh());
 
@@ -166,7 +153,7 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertInvalid("/b:root/b:bleh", element);
         assertValid("/b:root/b:howdycustom[text()='howdy']", element);
@@ -186,7 +173,7 @@ public class BeanTest extends AbstractAegisTest {
 
         ElementReader reader = new ElementReader(getResourceAsStream("bean4.xml"));
 
-        SimpleBean bean = (SimpleBean)type.readObject(reader, new Context());
+        SimpleBean bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("bleh", bean.getBleh());
         assertEquals("howdy", bean.getHowdy());
 
@@ -195,13 +182,13 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertValid("/b:root[@b:bleh='bleh']", element);
         assertValid("/b:root[@b:howdy='howdy']", element);
 
-        Element types = new Element("types", "xsd", XmlConstants.XSD);
-        Element schema = new Element("schema", "xsd", XmlConstants.XSD);
+        Element types = new Element("types", "xsd", SOAPConstants.XSD);
+        Element schema = new Element("schema", "xsd", SOAPConstants.XSD);
         types.addContent(schema);
 
         new Document(types);
@@ -226,7 +213,7 @@ public class BeanTest extends AbstractAegisTest {
 
         ElementReader reader = new ElementReader(getResourceAsStream("bean8.xml"));
 
-        SimpleBean bean = (SimpleBean)type.readObject(reader, new Context());
+        SimpleBean bean = (SimpleBean)type.readObject(reader, getContext());
         assertEquals("bleh", bean.getBleh());
         assertEquals("howdy", bean.getHowdy());
 
@@ -236,12 +223,12 @@ public class BeanTest extends AbstractAegisTest {
 
         ByteArrayOutputStream bos = new ByteArrayOutputStream();
         ElementWriter writer = new ElementWriter(bos, "root", "urn:Bean");
-        type.writeObject(bean, writer, new Context());
+        type.writeObject(bean, writer, getContext());
         writer.close();
         writer.flush();
 
         bos.close();
-
+        
         StaxBuilder builder = new StaxBuilder();
         Document doc = builder.build(new ByteArrayInputStream(bos.toByteArray()));
         Element element = doc.getRootElement();
@@ -268,13 +255,13 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertInvalid("/b:root[@b:howdy]", element);
         assertValid("/b:root/b:bleh[@xsi:nil='true']", element);
 
-        Element types = new Element("types", "xsd", XmlConstants.XSD);
-        Element schema = new Element("schema", "xsd", XmlConstants.XSD);
+        Element types = new Element("types", "xsd", SOAPConstants.XSD);
+        Element schema = new Element("schema", "xsd", SOAPConstants.XSD);
         types.addContent(schema);
 
         new Document(types);
@@ -284,7 +271,7 @@ public class BeanTest extends AbstractAegisTest {
         assertValid("//xsd:complexType[@name='bean']/xsd:attribute[@name='howdy']", schema);
         assertValid("//xsd:complexType[@name='bean']/xsd:sequence/xsd:element[@name='bleh']", schema);
     }
-
+    
     @Test
     public void testNillableInt() throws Exception {
         BeanTypeInfo info = new BeanTypeInfo(IntBean.class, "urn:Bean");
@@ -295,8 +282,8 @@ public class BeanTest extends AbstractAegisTest {
         type.setTypeMapping(mapping);
         type.setSchemaType(new QName("urn:Bean", "bean"));
 
-        Element types = new Element("types", "xsd", XmlConstants.XSD);
-        Element schema = new Element("schema", "xsd", XmlConstants.XSD);
+        Element types = new Element("types", "xsd", SOAPConstants.XSD);
+        Element schema = new Element("schema", "xsd", SOAPConstants.XSD);
         types.addContent(schema);
 
         new Document(types);
@@ -314,21 +301,21 @@ public class BeanTest extends AbstractAegisTest {
     }
     @Test
     public void testNillableIntMinOccurs1() throws Exception {
-        reg = new DefaultTypeMappingRegistry();
+        context = new AegisContext();
 
-        Configuration config = reg.getConfiguration();
+        TypeCreationOptions config = new TypeCreationOptions();
         config.setDefaultMinOccurs(1);
         config.setDefaultNillable(false);
-
-        reg.createDefaultMappings();
-        mapping = reg.createTypeMapping(true);
+        context.setTypeCreationOptions(config);
+        context.initialize();
+        mapping = context.getTypeMapping();
 
         BeanType type = (BeanType)mapping.getTypeCreator().createType(IntBean.class);
         type.setTypeClass(IntBean.class);
         type.setTypeMapping(mapping);
 
-        Element types = new Element("types", "xsd", XmlConstants.XSD);
-        Element schema = new Element("schema", "xsd", XmlConstants.XSD);
+        Element types = new Element("types", "xsd", SOAPConstants.XSD);
+        Element schema = new Element("schema", "xsd", SOAPConstants.XSD);
         types.addContent(schema);
 
         new Document(types);
@@ -342,54 +329,6 @@ public class BeanTest extends AbstractAegisTest {
         assertInvalid("//xsd:complexType[@name='IntBean']/xsd:sequence/xsd:element[@name='int1'][@nillable]",
                       schema);
     }
-    @Test
-    public void testByteMappings() throws Exception {
-        reg = new DefaultTypeMappingRegistry();
-        reg.createDefaultMappings();
-        mapping = reg.createTypeMapping(true);
-
-        BeanType type = (BeanType)mapping.getTypeCreator().createType(SimpleBean.class);
-        type.setTypeClass(SimpleBean.class);
-        type.setTypeMapping(mapping);
-
-
-        Element types = new Element("types", "xsd", XmlConstants.XSD);
-        Element schema = new Element("schema", "xsd", XmlConstants.XSD);
-        types.addContent(schema);
-
-        new Document(types);
-
-        type.writeSchema(schema);
-
-        assertValid("//xsd:complexType[@name='SimpleBean']/xsd:sequence/xsd:element[@name='littleByte']"
-                       + "/@type",
-                       schema);
-
-        assertValid("//xsd:complexType[@name='SimpleBean']/xsd:sequence/xsd:element[@name='bigByte']"
-                       + "/@type",
-                       schema);
-
-        Element element = new Element("root", "b", "urn:Bean");
-        new Document(element);
-        SimpleBean bean = new SimpleBean();
-        bean.setBigByte(new Byte((byte)0xfe));
-        bean.setLittleByte((byte)0xfd);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
-        Byte bb = new Byte((byte)0xfe);
-        String bbs = bb.toString();
-        addNamespace("n1", "http://services.aegis.cxf.apache.org");
-        assertValid("/b:root/n1:bigByte[text()='" + bbs + "']", element);
-
-        // Test reading
-        ElementReader reader = new ElementReader(getResourceAsStream("byteBeans.xml"));
-        bean = (SimpleBean)type.readObject(reader, new Context());
-        assertEquals(-5, bean.getLittleByte());
-        assertEquals(25, bean.getBigByte().byteValue());
-
-        reader.getXMLStreamReader().close();
-
-    }
-
     @Test
     public void testNullNonNillableWithDate() throws Exception {
         BeanTypeInfo info = new BeanTypeInfo(DateBean.class, "urn:Bean");
@@ -405,7 +344,7 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         // Make sure the date doesn't have an element. Its non nillable so it
         // just
@@ -424,15 +363,14 @@ public class BeanTest extends AbstractAegisTest {
         type.setSchemaType(new QName("urn:Bean", "bean"));
 
         PropertyDescriptor[] pds = info.getPropertyDescriptors();
-
-        assertEquals(5, pds.length);
+        assertEquals(4, pds.length);
 
         ExtendedBean bean = new ExtendedBean();
         bean.setHowdy("howdy");
 
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         assertValid("/b:root/b:howdy[text()='howdy']", element);
     }
@@ -457,16 +395,16 @@ public class BeanTest extends AbstractAegisTest {
         // Test writing
         Element element = new Element("root", "b", "urn:Bean");
         new Document(element);
-        type.writeObject(bean, new JDOMWriter(element), new Context());
+        type.writeObject(bean, new JDOMWriter(element), getContext());
 
         // Make sure the date doesn't have an element. Its non nillable so it
         // just
         // shouldn't be there.
 
-        addNamespace("xsi", XmlConstants.XSI_NS);
+        addNamespace("xsi", SOAPConstants.XSI_NS);
         assertValid("/b:root/b:data[@xsi:nil='true']", element);
 
-        bean = (ByteBean)type.readObject(new JDOMReader(element), new Context());
+        bean = (ByteBean)type.readObject(new JDOMReader(element), getContext());
         assertNotNull(bean);
         assertNull(bean.getData());
     }
