@@ -125,29 +125,20 @@ public class ContextPropertiesMappingTest extends Assert {
     }
     
     @Test
-    public void testUpdateWebServiceContextAttachmentsInOutMessage() {
-        doTestUpdateWebServiceContext(true);
-    }
-
-    @Test
-    public void testUpdateWebServiceContextAttachmentsInMessageContext() {
-        doTestUpdateWebServiceContext(false);
-    }
-
-    private void doTestUpdateWebServiceContext(boolean attachmentsInOutMessage) {
+    public void testUpdateWebServiceContext() {
         Exchange xchng = new ExchangeImpl();
         Message outMsg = new MessageImpl();
         List<Header> hdrList = new ArrayList<Header>();
         xchng.setOutMessage(outMsg);
         
         responseContext.put(MessageContext.HTTP_RESPONSE_CODE, RESPONSE_CODE);
-
+        
         MessageContext ctx = EasyMock.createMock(MessageContext.class);
         ctx.containsKey(MessageContext.HTTP_RESPONSE_CODE);
         EasyMock.expectLastCall().andReturn(true);
         ctx.get(MessageContext.HTTP_RESPONSE_CODE);
         EasyMock.expectLastCall().andReturn(RESPONSE_CODE);
-
+        
         ctx.containsKey(Header.HEADER_LIST);
         EasyMock.expectLastCall().andReturn(true);
         ctx.get(Header.HEADER_LIST);
@@ -157,17 +148,9 @@ public class ContextPropertiesMappingTest extends Assert {
 
         ctx.containsKey(MessageContext.HTTP_RESPONSE_HEADERS);
         EasyMock.expectLastCall().andReturn(false);
-
-        final Map<String, DataHandler> dataHandlers = new HashMap<String, DataHandler>();
-        dataHandlers.put("1", new DataHandler("one", "text/plain"));
-        if (attachmentsInOutMessage) {
-            outMsg.put(MessageContext.OUTBOUND_MESSAGE_ATTACHMENTS, dataHandlers);
-        } else {
-            ctx.get(MessageContext.OUTBOUND_MESSAGE_ATTACHMENTS);
-            EasyMock.expectLastCall().andReturn(dataHandlers);
-            ctx.remove(MessageContext.OUTBOUND_MESSAGE_ATTACHMENTS);
-            EasyMock.expectLastCall().andReturn(dataHandlers);
-        }
+        
+        ctx.get(MessageContext.OUTBOUND_MESSAGE_ATTACHMENTS);
+        EasyMock.expectLastCall().andReturn(null);
 
         EasyMock.replay(ctx);
         
@@ -175,11 +158,6 @@ public class ContextPropertiesMappingTest extends Assert {
         Integer respCode = (Integer)outMsg.get(Message.RESPONSE_CODE);
         assertNotNull("no response code set on out message", respCode);
         assertEquals("incorrect response code returned", RESPONSE_CODE, respCode);
-
-        if (attachmentsInOutMessage) {
-            assertNull(outMsg.get(MessageContext.OUTBOUND_MESSAGE_ATTACHMENTS));
-        }
-        assertNotNull(outMsg.getAttachments());
     }
 
     @Test
