@@ -26,6 +26,8 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.Calendar;
 import java.util.GregorianCalendar;
+import java.util.List;
+import java.util.Map;
 import java.util.SimpleTimeZone;
 import java.util.TimeZone;
 import java.util.concurrent.Executor;
@@ -39,12 +41,15 @@ import javax.jms.Queue;
 import javax.jms.QueueSender;
 import javax.jms.TextMessage;
 import javax.naming.NamingException;
+import javax.xml.namespace.QName;
 
 import org.apache.cxf.Bus;
 import org.apache.cxf.BusFactory;
 import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.configuration.Configurable;
 import org.apache.cxf.configuration.Configurer;
+import org.apache.cxf.helpers.CastUtils;
+import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.io.CachedOutputStream;
 import org.apache.cxf.message.Message;
 import org.apache.cxf.message.MessageImpl;
@@ -110,7 +115,9 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
             JMSProviderHub.connect(this, serverConfig, runtimePolicy);
             //Get a non-pooled session. 
             listenerSession = base.sessionFactory.get(base.targetDestination);
-            listenerThread = new JMSListenerThread(listenerSession);
+            listenerThread = new JMSListenerThread(listenerSession,
+                                                   getEndpointInfo() == null ? null 
+                                                       : getEndpointInfo().getName());
             listenerThread.start();
         } catch (JMSException ex) {
             getLogger().log(Level.SEVERE, "JMS connect failed with JMSException : ", ex);
@@ -266,13 +273,31 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
     
     protected class JMSListenerThread extends Thread {
         private final PooledSession listenSession;
-
-        public JMSListenerThread(PooledSession session) {
+        private final QName name;
+        public JMSListenerThread(PooledSession session, QName n) {
             listenSession = session;
+            name = n;
         }
 
         public void run() {
             try {
+                Executor executor = null;
+                if (executor == null) {
+                    WorkQueueManager wqm =
+                        base.bus.getExtension(WorkQueueManager.class);
+                    if (null != wqm) {
+                        if (name != null) {
+                            executor = wqm.getNamedWorkQueue("{" + name.getNamespaceURI() + "}" 
+                                                             + name.getLocalPart());
+                        }                        
+                        if (executor == null) {
+                            executor = wqm.getNamedWorkQueue("jms");
+                        }
+                        if (executor == null) {
+                            executor = wqm.getAutomaticWorkQueue();
+                        }
+                    }    
+                }
                 while (true) {
                     javax.jms.Message message = listenSession.consumer().receive();                   
                     if (message == null) {
@@ -284,14 +309,6 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
                     while (message != null) {
                         //REVISIT  to get the thread pool                        
                         //Executor executor = jmsDestination.callback.getExecutor();
-                        Executor executor = null;
-                        if (executor == null) {
-                            WorkQueueManager wqm =
-                                base.bus.getExtension(WorkQueueManager.class);
-                            if (null != wqm) {
-                                executor = wqm.getAutomaticWorkQueue();
-                            }    
-                        }
                         if (executor != null) {
                             try {
                                 executor.execute(new JMSExecutor(message));
@@ -371,8 +388,14 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
             // setup the message to be send back
             message.put(JMSConstants.JMS_REQUEST_MESSAGE, 
                         inMessage.get(JMSConstants.JMS_REQUEST_MESSAGE));
+            
+            if (!message.containsKey(JMSConstants.JMS_SERVER_RESPONSE_HEADERS)
+                && inMessage.containsKey(JMSConstants.JMS_SERVER_RESPONSE_HEADERS)) {
+                message.put(JMSConstants.JMS_SERVER_RESPONSE_HEADERS,
+                            inMessage.get(JMSConstants.JMS_SERVER_RESPONSE_HEADERS));
+            }
             message.setContent(OutputStream.class,
-                               new JMSOutputStream(inMessage));
+                               new JMSOutputStream(inMessage, message));
         }
         
         protected Logger getLogger() {
@@ -383,21 +406,23 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
     private class JMSOutputStream extends CachedOutputStream {
                 
         private Message inMessage;
+        private Message outMessage;
         private javax.jms.Message reply;
         private Queue replyTo;
         private QueueSender sender;
         
         // setup the ByteArrayStream
-        public JMSOutputStream(Message m) {
+        public JMSOutputStream(Message m, Message o) {
             super();
             inMessage = m;
+            outMessage = o;
         }
         
         //to prepear the message and get the send out message
         private void commitOutputMessage() throws IOException {
             
             JMSMessageHeadersType headers =
-                (JMSMessageHeadersType) inMessage.get(JMSConstants.JMS_SERVER_RESPONSE_HEADERS);
+                (JMSMessageHeadersType) outMessage.get(JMSConstants.JMS_SERVER_RESPONSE_HEADERS);
             javax.jms.Message request = 
                 (javax.jms.Message) inMessage.get(JMSConstants.JMS_REQUEST_MESSAGE);              
             
@@ -429,7 +454,8 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
                     if (getLogger().isLoggable(Level.FINE)) {
                         getLogger().log(Level.FINE, "The response message is ["
                                         + (replyObj instanceof String 
-                                           ? (String)replyObj : new String((byte[])replyObj))
+                                           ? (String)replyObj 
+                                               : IOUtils.newStringFromBytes((byte[])replyObj))
                                     + "]");
                     }
 
@@ -439,8 +465,12 @@ public class JMSDestination extends AbstractMultiplexDestination implements Conf
                                          msgType);
 
                     setReplyCorrelationID(request, reply);
-                    
                     base.setMessageProperties(headers, reply);
+                    //ensure that the contentType is set to the out jms message header
+                    base.setContentToProtocalHeader(outMessage);
+                    Map<String, List<String>> protHeaders = 
+                        CastUtils.cast((Map<?, ?>)outMessage.get(Message.PROTOCOL_HEADERS));
+                    base.addProtocolHeaders(reply, protHeaders);
 
                     sendResponse();
                     
