@@ -24,12 +24,16 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
+import java.util.List;
+
 import javax.jws.WebService;
 import javax.xml.namespace.QName;
 import javax.xml.ws.WebFault;
 import javax.xml.ws.WebServiceClient;
 
 import org.apache.cxf.common.i18n.Message;
+import org.apache.cxf.helpers.FileUtils;
+import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.tools.common.ProcessorTestBase;
 import org.apache.cxf.tools.common.ToolConstants;
 import org.apache.cxf.tools.util.AnnotationUtil;
@@ -74,10 +78,10 @@ public class CodeGenBugTest extends ProcessorTestBase {
     @After
     public void tearDown() {
         super.tearDown();
-        processor = null;
+        //processor = null;
         env = null;
     }
-
+    
     @Test
     // Test for CXF-1678
     public void testLogicalOnlyWSDL() throws Exception {
@@ -113,7 +117,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/bug305773/hello_world.wsdl"));
         processor.setContext(env);
         processor.execute();
-        Class clz = classLoader.loadClass("org.apache.hello_world_soap_http.GreeterImpl");
+        Class clz = classLoader.loadClass("org.apache.cxf.w2j.hello_world_soap_http.GreeterImpl");
 
         WebService webServiceAnn = AnnotationUtil.getPrivClassAnnotation(clz, WebService.class);
         assertTrue("Impl class should note generate name property value in webService annotation",
@@ -138,7 +142,8 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
     @Test
     public void testNamespacePackageMapping1() throws Exception {
-        env.addNamespacePackageMap("http://apache.org/hello_world_soap_http/types", "org.apache.types");
+        env.addNamespacePackageMap("http://cxf.apache.org/w2j/hello_world_soap_http/types",
+                                   "org.apache.types");
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/hello_world.wsdl"));
         processor.setContext(env);
         processor.execute();
@@ -161,8 +166,9 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
     @Test
     public void testNamespacePackageMapping2() throws Exception {
-        env.addNamespacePackageMap("http://apache.org/hello_world_soap_http", "org.apache");
-        env.addNamespacePackageMap("http://apache.org/hello_world_soap_http/types", "org.apache.types");
+        env.addNamespacePackageMap("http://cxf.apache.org/w2j/hello_world_soap_http", "org.apache");
+        env.addNamespacePackageMap("http://cxf.apache.org/w2j/hello_world_soap_http/types",
+                                   "org.apache.types");
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/hello_world.wsdl"));
         processor.setContext(env);
         processor.execute();
@@ -212,7 +218,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         BufferedInputStream filebuffer = new BufferedInputStream(fileinput);
         byte[] buffer = new byte[(int)file.length()];
         filebuffer.read(buffer);
-        String content = new String(buffer);
+        String content = IOUtils.newStringFromBytes(buffer);
         assertTrue("wsdl location should be url style in build.xml", content.indexOf("param1=\"file:") > -1);
 
     }
@@ -233,8 +239,8 @@ public class CodeGenBugTest extends ProcessorTestBase {
         File iona = new File(com, "iona");
         assertFalse("Generated file has been excluded", iona.exists());
 
-        File implFile = new File(output, "org/apache/hello_world_soap_http/Greeter.java");
-        String str = getStringFromFile(implFile);
+        File implFile = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/Greeter.java");
+        String str = FileUtils.getStringFromFile(implFile);
         assertTrue(str.indexOf("com.iona.BareDocumentResponse") > 0);
 
         File org = new File(output, "org");
@@ -273,7 +279,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
     @Test
     public void testDefaultLoadNSMappingOFF() throws Exception {
-        String[] args = new String[] {"-dns", "false", "-d", output.getCanonicalPath(),
+        String[] args = new String[] {"-dns", "false", "-d", output.getCanonicalPath(), "-noAddressBinding",
                                       getLocation("/wsdl2java_wsdl/basic_callback.wsdl")};
 
         WSDLToJava.main(args);
@@ -296,7 +302,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
     @Test
     public void testDefaultLoadNSMappingON() throws Exception {
-        String[] args = new String[] {"-d", output.getCanonicalPath(),
+        String[] args = new String[] {"-d", output.getCanonicalPath(), "-noAddressBinding",
                                       getLocation("/wsdl2java_wsdl/basic_callback.wsdl")};
 
         WSDLToJava.main(args);
@@ -331,7 +337,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         }
         try {
             Class clz = classLoader
-                .loadClass("org.apache.hello_world_soap_http.types.CreateProcess$MyProcess");
+                .loadClass("org.apache.cxf.w2j.hello_world_soap_http.types.CreateProcess$MyProcess");
             assertNotNull("Customization binding code should be generated", clz);
         } catch (ClassNotFoundException e) {
             fail("Can not load the inner class MyProcess, the customization failed: \n" + e.getMessage());
@@ -352,7 +358,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         }
         try {
             Class clz = classLoader
-                .loadClass("org.apache.hello_world_soap_http.types.CreateProcess$MyProcess");
+                .loadClass("org.apache.cxf.w2j.hello_world_soap_http.types.CreateProcess$MyProcess");
             assertNotNull("Customization binding code should be generated", clz);
         } catch (ClassNotFoundException e) {
             e.printStackTrace();
@@ -378,9 +384,9 @@ public class CodeGenBugTest extends ProcessorTestBase {
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/helloworld_noservice_import.wsdl"));
         processor.setContext(env);
         processor.execute();
-        Class cls = classLoader.loadClass("org.apache.hello_world1.Greeter");
+        Class cls = classLoader.loadClass("org.apache.cxf.w2j.hello_world1.Greeter");
         assertNotNull(cls);
-        cls = classLoader.loadClass("org.apache.hello_world2.Greeter2");
+        cls = classLoader.loadClass("org.apache.cxf.w2j.hello_world2.Greeter2");
     }
 
     @Test
@@ -391,11 +397,14 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
 
-        Class clz = classLoader.loadClass("org.apache.hello_world_soap_http.service.SOAPServiceTest1");
+        Class clz = classLoader
+            .loadClass("org.apache.cxf.w2j.hello_world_soap_http.service.SOAPServiceTest1");
         WebServiceClient webServiceClient = AnnotationUtil
             .getPrivClassAnnotation(clz, WebServiceClient.class);
-        assertEquals("http://apache.org/hello_world_soap_http/service", webServiceClient.targetNamespace());
-        File file = new File(output, "org/apache/hello_world_soap_http/Greeter_SoapPortTest1_Client.java");
+        assertEquals("http://cxf.apache.org/w2j/hello_world_soap_http/service",
+                     webServiceClient.targetNamespace());
+        File file = new File(output, 
+                             "org/apache/cxf/w2j/hello_world_soap_http/Greeter_SoapPortTest1_Client.java");
         FileInputStream fin = new FileInputStream(file);
         byte[] buffer = new byte[30000];
         int index = -1;
@@ -404,7 +413,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         while (size != -1) {
             bout.write(buffer, 0, size);
             index = bout.toString()
-                .indexOf("new QName(\"http://apache.org/hello_world_soap_http/service\","
+                .indexOf("new QName(\"http://cxf.apache.org/w2j/hello_world_soap_http/service\","
                         + " \"SOAPService_Test1\")");
             if (index > 0) {
                 break;
@@ -428,6 +437,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
     @Test
     public void testDefatultNsMap() throws Exception {
         env.put(ToolConstants.CFG_ALL, ToolConstants.CFG_ALL);
+        env.put(ToolConstants.CFG_NO_ADDRESS_BINDING, ToolConstants.CFG_NO_ADDRESS_BINDING);
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/cxf492/locator.wsdl"));
         processor.setContext(env);
         processor.execute();
@@ -488,7 +498,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
     @Test
     public void testDefaultNSWithPkg() throws Exception {
-        String[] args = new String[] {"-d", output.getCanonicalPath(), "-p", "org.cxf",
+        String[] args = new String[] {"-d", output.getCanonicalPath(), "-p", "org.cxf", "-noAddressBinding",
                                       getLocation("/wsdl2java_wsdl/basic_callback.wsdl")};
 
         WSDLToJava.main(args);
@@ -524,8 +534,18 @@ public class CodeGenBugTest extends ProcessorTestBase {
 
         WSDLToJava.main(args);
 
-        assertFileEquals(getClass().getResource("expected/expected_hello_mime").getFile(),
-                         output.getCanonicalPath() + "/org/apache/hello_world_mime/Hello.java");
+        String str1 = "SOAPBinding.ParameterStyle.BARE";
+        String str2 = "javax.xml.ws.Holder";
+        String str3 = "org.apache.cxf.mime.Address";
+        String str4 = "http://cxf.apache.org/w2j/hello_world_mime/types";
+                
+        String file = getStringFromFile(new File(output.getCanonicalPath() 
+                                        + "/org/apache/cxf/w2j/hello_world_mime/Hello.java"));
+        
+        assertTrue(file.contains(str1));
+        assertTrue(file.contains(str2));
+        assertTrue(file.contains(str3));
+        assertTrue(file.contains(str4));
     }
 
     @Test
@@ -535,7 +555,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
 
-        String results = getStringFromFile(new File(output.getCanonicalPath(), 
+        String results = FileUtils.getStringFromFile(new File(output.getCanonicalPath(), 
                                                     "org/apache/sayhi/SayHi.java"));
         assertTrue(results.trim().length() > 0);
         
@@ -551,14 +571,10 @@ public class CodeGenBugTest extends ProcessorTestBase {
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/bug627/hello_world.wsdl"));
         env.put(ToolConstants.CFG_BINDING, getLocation("/wsdl2java_wsdl/bug627/async_binding.xml"));
         processor.setContext(env);
-        try {
-            processor.execute();
-        } catch (Exception ex) {
-            //ignore
-        }
+        processor.execute();
 
 
-        Class clz = classLoader.loadClass("org.apache.hello_world_soap_http.Greeter");
+        Class clz = classLoader.loadClass("org.apache.cxf.w2j.hello_world_soap_http.Greeter");
         assertEquals(3, clz.getDeclaredMethods().length);
 
     }
@@ -574,15 +590,17 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
 
-        File file = new File(output, "org/apache/hello_world_soap_http");
+        File file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http");
         assertEquals(4, file.list().length);
-        file = new File(output, "org/apache/hello_world_soap_http/DocLitBare_DocLitBarePort_Client.java");
+        file = new File(output,
+                        "org/apache/cxf/w2j/hello_world_soap_http/DocLitBare_DocLitBarePort_Client.java");
         assertTrue("DocLitBare_DocLitBarePort_Client is not found", file.exists());
-        file = new File(output, "org/apache/hello_world_soap_http/DocLitBare_DocLitBarePort_Server.java");
+        file = new File(output,
+                        "org/apache/cxf/w2j/hello_world_soap_http/DocLitBare_DocLitBarePort_Server.java");
         assertTrue("DocLitBare_DocLitBarePort_Server is not found", file.exists());
-        file = new File(output, "org/apache/hello_world_soap_http/Greeter_GreeterPort_Client.java");
+        file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/Greeter_GreeterPort_Client.java");
         assertTrue("Greeter_GreeterPort_Client is not found", file.exists());
-        file = new File(output, "org/apache/hello_world_soap_http/Greeter_GreeterPort_Server.java");
+        file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/Greeter_GreeterPort_Server.java");
         assertTrue("Greeter_GreeterPort_Server is not found", file.exists());
     }
     
@@ -602,7 +620,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
         
-        File file = new File(output, "org/apache/hello_world_soap_http/MyService.java");
+        File file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/MyService.java");
         assertTrue("MyService is not found", file.exists());
         
     }
@@ -615,10 +633,10 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
         
-        File file = new File(output, "org/apache/hello_world_soap_http/SOAPService.java");
+        File file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/SOAPService.java");
         assertTrue("SOAPService is not found", file.exists());
         
-        file = new File(output, "org/apache/hello_world_soap_http/MyService.java");
+        file = new File(output, "org/apache/cxf/w2j/hello_world_soap_http/MyService.java");
         assertFalse("MyService should not be generated", file.exists());
         
     }
@@ -634,8 +652,9 @@ public class CodeGenBugTest extends ProcessorTestBase {
             fail("exception should be thrown");
         } catch (Exception e) {
             String expectedErrorMsg = "Part <in> in Message " 
-                + "<{http://apache.org/hello_world_soap_http}greetMeRequest> referenced Type " 
-                + "<{http://apache.org/hello_world_soap_http/types}greetMee> can not be found in the schemas";
+                + "<{http://cxf.apache.org/w2j/hello_world_soap_http}greetMeRequest> referenced Type " 
+                + "<{http://cxf.apache.org/w2j/hello_world_soap_http/types}greetMee> can not be "
+                + "found in the schemas";
             assertTrue("Fail to create java parameter exception should be thrown",
                        e.getMessage().indexOf(expectedErrorMsg) > -1);
         }
@@ -652,11 +671,11 @@ public class CodeGenBugTest extends ProcessorTestBase {
         
         processor.execute();
         File file = new File(output.getCanonicalPath() + "/build.xml");
-        String str = getStringFromFile(file);
-        assertTrue(str.indexOf("org.apache.hello_world_soap_http.Greeter_SoapPortTest1_Client") > -1);
-        assertTrue(str.indexOf("org.apache.hello_world_soap_http.Greeter_SoapPortTest2_Client") > -1);
-        assertTrue(str.indexOf("org.apache.hello_world_soap_http.Greeter_SoapPortTest1_Server") > -1);
-        assertTrue(str.indexOf("org.apache.hello_world_soap_http.Greeter_SoapPortTest2_Server") > -1);        
+        String str = FileUtils.getStringFromFile(file);
+        assertTrue(str.indexOf("org.apache.cxf.w2j.hello_world_soap_http.Greeter_SoapPortTest1_Client") > -1);
+        assertTrue(str.indexOf("org.apache.cxf.w2j.hello_world_soap_http.Greeter_SoapPortTest2_Client") > -1);
+        assertTrue(str.indexOf("org.apache.cxf.w2j.hello_world_soap_http.Greeter_SoapPortTest1_Server") > -1);
+        assertTrue(str.indexOf("org.apache.cxf.w2j.hello_world_soap_http.Greeter_SoapPortTest2_Server") > -1);
     }
  
     @Test
@@ -728,7 +747,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
             processor.setContext(env);
             processor.execute();
 
-            String results = getStringFromFile(new File(output.getCanonicalPath(), 
+            String results = FileUtils.getStringFromFile(new File(output.getCanonicalPath(), 
                                                         "org/tempuri/GreeterRPCLit.java"));
             assertTrue(results.indexOf("@WebParam(partName  =  \"inInt\",  name  =  \"inInt\")") != -1);
             assertTrue(results.indexOf("Style.RPC") != -1);
@@ -763,7 +782,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
 
-        String results = getStringFromFile(new File(output.getCanonicalPath(), 
+        String results = FileUtils.getStringFromFile(new File(output.getCanonicalPath(), 
                                                     "soapinterface/ems/esendex/com/AccountServiceSoap.java"));
         assertTrue(results.indexOf("public  int  getMessageLimit") != -1);
         assertTrue(results.indexOf("name  =  \"MessengerHeader") != -1);
@@ -780,10 +799,10 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
         Class clz = classLoader
-        .loadClass("org.apache.hello_world.messages.CustomizedFault");
+        .loadClass("org.apache.cxf.w2j.hello_world.messages.CustomizedFault");
         assertNotNull("Customization Fault Class is not generated", clz);
         Class serviceClz = classLoader
-        .loadClass("org.apache.hello_world.services.CustomizedService");
+        .loadClass("org.apache.cxf.w2j.hello_world.services.CustomizedService");
         assertNotNull("Customization Fault Class is not generated", serviceClz);
 
     }
@@ -796,7 +815,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
         
-        Class clz = classLoader.loadClass("org.apache.hello_world_soap_http.Greeter");
+        Class<?> clz = classLoader.loadClass("org.apache.cxf.w2j.hello_world_soap_http.Greeter");
         
         Method method1 = clz.getMethod("greetMeSometimeAsync", new Class[] {java.lang.String.class,
                                                                             javax.xml.ws.AsyncHandler.class});
@@ -825,7 +844,8 @@ public class CodeGenBugTest extends ProcessorTestBase {
         env.put(ToolConstants.CFG_BINDING, getLocation("/wsdl2java_wsdl/cxf1094/jaxbbinding.xml"));
         processor.setContext(env);
         processor.execute();
-        Class clz = classLoader.loadClass("org.apache.hello_world_soap_http.types.CreateProcess$MyProcess");
+        Class clz = classLoader
+            .loadClass("org.apache.cxf.w2j.hello_world_soap_http.types.CreateProcess$MyProcess");
         assertNotNull("Failed to generate customized class for hello_world.wsdl" , clz);
        
         env.put(ToolConstants.CFG_WSDLURL, 
@@ -846,7 +866,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.setContext(env);
         processor.execute();
         Class clz = classLoader
-        .loadClass("org.apache.hello_world_soap_http.Greeter");
+        .loadClass("org.apache.cxf.w2j.hello_world_soap_http.Greeter");
         assertNotNull("Failed to generate SEI class", clz);
         Method[] methods = clz.getMethods();
         assertEquals("jaxws binding file parse error, number of generated method is not expected"
@@ -915,7 +935,7 @@ public class CodeGenBugTest extends ProcessorTestBase {
             assertTrue(e.getMessage().indexOf("Summary:  Failures: 5, Warnings: 0") != -1);
         }
     }
-    
+  
     @Test
     public void testTwoJaxwsBindingFile() throws Exception {
         env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/hello_world.wsdl"));
@@ -925,15 +945,56 @@ public class CodeGenBugTest extends ProcessorTestBase {
         processor.execute();
         File file = new File(output, "org/mypkg");
         assertEquals(23, file.listFiles().length);
-        Class clz = classLoader.loadClass("org.mypkg.MyService");
+        Class<?> clz = classLoader.loadClass("org.mypkg.MyService");
         assertNotNull("Customized service class is not found", clz);
         clz = classLoader.loadClass("org.mypkg.MyGreeter");
         assertNotNull("Customized SEI class is not found", clz);
         Method customizedMethod = clz.getMethod("myGreetMe", new Class[] {String.class});
         assertNotNull("Customized method 'myGreetMe' in MyGreeter.class is not found", customizedMethod);
     }
+
     
     
+    @Test
+    public void testJaxwsBindingJavaDoc() throws Exception {
+        env.put(ToolConstants.CFG_WSDLURL, getLocation("/wsdl2java_wsdl/hello_world.wsdl"));
+        env.put(ToolConstants.CFG_BINDING, getLocation("/wsdl2java_wsdl/cxf1152/jaxws1.xml"));
+        processor.setContext(env);
+        processor.execute();
+
+        List<String> results1 = FileUtils.readLines(new File(output.getCanonicalPath(), 
+            "org/mypkg/MyGreeter.java"));
+                
+        assertTrue(results1.contains(" * this is package javadoc"));
+        assertTrue(results1.contains(" * this is class javadoc"));
+        assertTrue(results1.contains("     * this is method javadoc"));
+        
+        List<String> results2 = FileUtils.readLines(new File(output.getCanonicalPath(), 
+            "org/mypkg/SOAPService.java")); 
+        
+        boolean match1 = false;
+        boolean match2 = false;
+        for (String str : results2) {
+            if (str.contains("package javadoc")) {
+                match1 = true;
+            }
+            if (str.contains("class javadoc")) {
+                match2 = true;
+            }
+        }
+        assertTrue(match1);
+        assertTrue(match2);
+        
+    }
+    
+    @Test
+    public void testWSAActionAnno() throws Exception {
+        env.put(ToolConstants.CFG_WSDLURL, 
+                getLocation("/wsdl2java_wsdl/cxf1209/hello_world_fault.wsdl"));        
+        processor.setContext(env);
+        processor.execute();
+    }
+    
     @Test
     public void testCXF964() throws Exception {
         env.put(ToolConstants.CFG_WSDLURL, 
